fangs-package: fangs: Feature Allocation Neighborhood Greedy Search...

fangs-packageR Documentation

fangs: Feature Allocation Neighborhood Greedy Search Algorithm

Description

A neighborhood-based, greedy search algorithm is performed to estimate a feature allocation by minimizing the expected loss based on posterior samples from the feature allocation distribution. The method is described in Dahl, Johnson, and Andros (2023) "Comparison and Bayesian Estimation of Feature Allocations" \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2023.2204136")}.

Author(s)

Maintainer: David B. Dahl dahl@stat.byu.edu (ORCID)

Authors:

Other contributors:

  • Authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]

See Also

Useful links:


fangs documentation built on March 8, 2026, 9:08 a.m.