| fangs-package | R Documentation |
A neighborhood-based, greedy search algorithm is performed to estimate a feature allocation by minimizing the expected loss based on posterior samples from the feature allocation distribution. The method is described in Dahl, Johnson, and Andros (2023) "Comparison and Bayesian Estimation of Feature Allocations" \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2023.2204136")}.
Maintainer: David B. Dahl dahl@stat.byu.edu (ORCID)
Authors:
R. Jacob Andros androsrj@gmail.com (ORCID)
Devin J. Johnson devin.j.johnson7@gmail.com (ORCID)
Other contributors:
Authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.